@@ -133,7 +133,7 @@ class DotFigure(Directive):
                     '"%s" directive may not both specify an external file '
                     'and have content.' % self.name)
             dot_file = NamedTemporaryFile()
-            dot_file.writelines(self.content)
+            dot_file.writelines(s.encode('utf-8') for s in self.content)
             dot_file.seek(0)
             command_args['stdin'] = dot_file
         elif 'file' in self.options:
